<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","");
define("_SUBJECT","");
define("_PRIVATEMESSAGES","  ");
define("_CHECKALL"," ");
define("_FROM","");
define("_DATE","");
define("_DONTHAVEMESSAGES","   ");
define("_NOTREAD"," ");
define("_MSGSTATUS","");
define("_PRIVATEMESSAGE"," ");
define("_INDEX","Index");
define("_SENT","");
define("_PREVIOUSMESSAGE"," ");
define("_NEXTMESSAGE"," ");
define("_PROFILE","");
define("_ABOUTPOSTING"," ");
define("_ALLREGCANPOST","        .");
define("_TO","");
define("_MESSAGEICON","");
define("_MESSAGE","");
define("_HTML","HTML");
define("_PMON",".");
define("_PMOFF",".");
define("_BBCODE","BBCode");
define("_WROTE","");
define("_OPTIONS","");
define("_HTMLDISSABLE"," HTML");
define("_BBCODEDISSABLE"," <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> on this Post");
define("_SMILEDISSABLE"," <a href=\"bb_smilies.php\" target=\"_blank\"><i></i></a> on this Post");
define("_CANCELREPLY","");
define("_CANCELSEND"," ");
define("_CLEAR","");
define("_SUBMIT","");
define("_USERNOTINDB","    .");
define("_CHECKNAMEANDTRY","     .");
define("_MSGPOSTED","   .");
define("_RETURNTOPMSG","      .");
define("_MSGDELETED","  .");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")
define("_DELETESELECTED","Delete Selected");
define("_SENDNEWMSG","Send New Message");
define("_REPLY","Reply");
define("_NOSUBJECT","There is not a Subject for your Message.");
define("_NOMESSAGE","There is not a Message. Please write a message!");

?>